Struct vp9_parser::ivf::Ivf
source · [−]pub struct Ivf<R> { /* private fields */ }Expand description
IVF is a simple container format for raw VP9 data.
Implementations
The framerate of the video (frame_rate_rate * frame_rate_scale).
Example: 24 fps with a scale of 1000 -> 24000
Divider of the seconds.
Number of frames stored inside the IVF. A frame can contain a frame or a super frame.