Struct vp9_parser::Frame [−][src]
pub struct Frame { /* fields omitted */ }A VP9 frame.
Implementations
impl Frame[src]
pub fn compressed_header_data(&self) -> &[u8][src]
Returns a slice into the data of the compressed header.
pub fn compressed_header_and_tile_data(&self) -> &[u8][src]
Returns a slice into the data of the compressed header and tile data.
pub fn tile_data(&self) -> &[u8][src]
Returns a slice into the data of the tile data.
pub fn profile(&self) -> Profile[src]
The profile the frame is using.
pub fn show_existing_frame(&self) -> bool[src]
Indicates that the frame indexed by frame_to_show_map_idx is to be displayed.
The frame contains no actual frame data.
pub fn frame_to_show_map_idx(&self) -> Option<u8>[src]
Specifies the frame to be displayed. It is only available if show_existing_frame is true.
pub fn last_frame_type(&self) -> FrameType[src]
The frame type of the previous frame.
pub fn frame_type(&self) -> FrameType[src]
The frame type of this frame.
pub fn error_resilient_mode(&self) -> bool[src]
Indicates that error resilient mode is enabled.
Error resilient mode allows the syntax of a frame to be decoded independently of previous frames.
pub fn intra_only(&self) -> bool[src]
Indicates that a frame is an intra-only frame.
A key frame is different to an intra-only frame even though both only use
intra prediction. The difference is that a key frame fully resets the decoding process.
pub fn reset_frame_context(&self) -> FrameType[src]
Specifies whether the frame context should be reset to default values.
pub fn ref_frame_indices(&self) -> &[u8; 3][src]
The indices of the used reference frames.
pub fn last_ref_frame_index(&self) -> u8[src]
Last reference frame index.
pub fn golden_ref_frame_index(&self) -> u8[src]
Golden reference frame index.
pub fn alt_ref_frame_index(&self) -> u8[src]
Alternate reference frame index.
pub fn ref_frame_sign_bias(&self) -> &[bool; 4][src]
Specifies the intended direction of the motion vector in time for each reference frame.
pub fn allow_high_precision_mv(&self) -> bool[src]
Specifies the precision of the motion vectors.
False = quarter precision, True = eighth precision.
pub fn refresh_frame_context(&self) -> bool[src]
Specifies that the probabilities computed for this frame should be stored for reference by future frames.
pub fn refresh_frame_flags(&self) -> u8[src]
Contains a bitmask that specifies which reference frame slots will be updated with the current frame after it is decoded.
First bit = first frame (1). Last bit = last frame (8).
pub fn frame_parallel_decoding_mode(&self) -> bool[src]
Specifies if parallel decoding mode is activated.
pub fn frame_context_idx(&self) -> u8[src]
Specifies which frame context to use.
pub fn uncompressed_header_size(&self) -> usize[src]
The size of the uncompressed header.
pub fn compressed_header_size(&self) -> usize[src]
The size of the uncompressed header.
pub fn tile_size(&self) -> usize[src]
The size of the tile data.
pub fn color_depth(&self) -> ColorDepth[src]
The color depth of the frame.
pub fn color_space(&self) -> ColorSpace[src]
The color space of the frame.
pub fn color_range(&self) -> ColorRange[src]
The color range of the frame.
pub fn subsampling(&self) -> Subsampling[src]
The subsampling the frame is using.
pub fn subsampling_x(&self) -> bool[src]
Indicates if sub sampling is used along the x axis.
pub fn subsampling_y(&self) -> bool[src]
Indicates if sub sampling is used along the y axis.
pub fn width(&self) -> u16[src]
The width of the frame.
pub fn height(&self) -> u16[src]
The height of the frame.
pub fn render_width(&self) -> u16[src]
A hint for the application for the desired width to render.
pub fn render_height(&self) -> u16[src]
A hint for the application for the desired height to render.
pub fn mi_cols(&self) -> u16[src]
A variable holding the vertical location of the block in units of 8x8 pixels.
pub fn mi_rows(&self) -> u16[src]
A variable holding the horizontal location of the block in units of 8x8 pixels.
pub fn tile_rows_log2(&self) -> u8[src]
The base 2 logarithm of the height of each tile (where the height is measured in units of 8x8 blocks)
pub fn tile_cols_log2(&self) -> u8[src]
The base 2 logarithm of the width of each tile (where the width is measured in units of 8x8 blocks)
pub fn interpolation_filter(&self) -> InterpolationFilter[src]
The type of filter used in inter prediction.
pub fn loop_filter_level(&self) -> u8[src]
The loop filter strength.
pub fn loop_filter_sharpness(&self) -> u8[src]
The loop filter sharpness.
pub fn loop_filter_delta_enabled(&self) -> bool[src]
Indicates that the filter level depends on the mode and reference frame used to predict a block.
pub fn update_ref_delta(&self) -> bool[src]
Indicates that the the bitstream contains the syntax element loop_filter_ref_delta.
pub fn loop_filter_ref_deltas(&self) -> &[i8; 4][src]
Contains the adjustment needed for the filter level based on the chosen reference frame.
pub fn update_mode_delta(&self) -> bool[src]
Indicates that the the bitstream contains the syntax element loop_filter_mode_deltas.
pub fn loop_filter_mode_deltas(&self) -> &[i8; 2][src]
Contains the adjustment needed for the filter level based on the chosen mode.
pub fn base_q_idx(&self) -> i32[src]
The base frame qindex. This is used for Y AC coefficients and as the base value for the other quantizers.
pub fn delta_q_y_dc(&self) -> i32[src]
The Y DC quantizer relative to base_q_idx.
pub fn delta_q_uv_dc(&self) -> i32[src]
The UV DC quantizer relative to base_q_idx.
pub fn delta_q_uv_ac(&self) -> i32[src]
The UV AC quantizer relative to base_q_idx.
pub fn lossless(&self) -> bool[src]
Indicates that the frame is coded using a special 4x4 transform designed for encoding frames that are bit-identical with the original frames.
pub fn segmentation_enabled(&self) -> bool[src]
Specifies that this frame makes use of the segmentation tool.
pub fn segmentation_update_map(&self) -> bool[src]
Specifies that the segmentation map should be updated during the decoding of this frame.
pub fn segment_tree_probs(&self) -> &[u8; 7][src]
The probability values to be used when decoding segment_id.
pub fn segment_pred_probs(&self) -> &[u8; 3][src]
The probability values to be used when decoding seg_id_predicted.
pub fn segmentation_temporal_update(&self) -> bool[src]
Indicates that the updates to the segmentation map are coded relative to the existing segmentation map.
pub fn segmentation_update_data(&self) -> bool[src]
Indicates that new parameters are about to be specified for each segment.
pub fn segmentation_abs_or_delta_update(&self) -> bool[src]
Indicates that the segmentation parameters represent the actual values to be used, otherwise the segmentation parameters represent adjustments relative to the standard values.
pub fn segment_feature_active(&self) -> &[[bool; 4]; 8][src]
Indicates that the corresponding feature is used for the reference frames.
pub fn segment_feature_data(&self) -> &[[i16; 4]; 8][src]
Specifies the values of the active segment features of the reference frames.