Struct vp9_parser::ivf::Ivf[][src]

pub struct Ivf<R> { /* fields omitted */ }

IVF is a simple container format for raw VP9 data.

Implementations

impl<R: Read> Ivf<R>[src]

pub fn new(reader: R) -> Result<Self, IvfError>[src]

Creates a new IVF using the given reader.

pub fn width(&self) -> u16[src]

The initial width of the video.

pub fn height(&self) -> u16[src]

The initial height of the video.

pub fn frame_rate_rate(&self) -> u32[src]

The framerate of the video (frame_rate_rate * frame_rate_scale).

Example: 24 fps with a scale of 1000 -> 24000

pub fn frame_rate_scale(&self) -> u32[src]

Divider of the seconds.

pub fn frame_count(&self) -> u32[src]

Number of frames stored inside the IVF. A frame can contain a frame or a super frame.

pub fn read_frame(&mut self) -> Result<Option<Frame>, IvfError>[src]

Reads the next frame inside the IVF. Returns None if the end of the file has been reached.

A frame contains a VP9 bitstream packet which can contain either a normal frame or a super frame.